@@ -5,7 +5,7 @@ from bluer_options.terminal import show_usage, xtra
 
 def options(mono: bool):
     return xtra(
-        "dryrun,~log,path=<path>",
+        "background,dryrun,~log,path=<path>",
         mono=mono,
     )
 
